==> haskell-decimal-0.5.2-225-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Decimal
version:              0.5.2
visibility:           public
id:                   Decimal-0.5.2-Ee0YaQP1EcK8GFHRFQrAau
key:                  Decimal-0.5.2-Ee0YaQP1EcK8GFHRFQrAau
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018, 2021.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  eb409fd21932ab813a3f4e3a1aec16fe
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/Decimal-0.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Decimal-0.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Decimal-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-decimal
hs-libraries:         HSDecimal-0.5.2-Ee0YaQP1EcK8GFHRFQrAau
depends:              base-4.18.2.1 deepseq-1.4.8.1
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-decimal-0.5.2-226-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Decimal
version:              0.5.2
visibility:           public
id:                   Decimal-0.5.2-1QLMM6hywMmG42YT7nD3xx
key:                  Decimal-0.5.2-1QLMM6hywMmG42YT7nD3xx
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018, 2021.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  448514e22ffb27869722b9630cd06546
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/Decimal-0.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Decimal-0.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Decimal-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-decimal
hs-libraries:         HSDecimal-0.5.2-1QLMM6hywMmG42YT7nD3xx
depends:              base-4.18.2.1 deepseq-1.4.8.1
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
